@@ -1,13 +1,16 @@
 package BioX::Workflow::Command::validate;
+
 use v5.10;
+
 use MooseX::App::Command;
+use namespace::autoclean;
 
 extends 'BioX::Workflow::Command';
 with 'BioX::Workflow::Command::Utils::Log';
 with 'BioX::Workflow::Command::Utils::Files';
 
-command_short_description 'Validate your workflow';
-command_long_description 'Validate your workflow';
+command_short_description 'Validate your workflow.';
+command_long_description 'Validate your workflow.';
 
 sub execute {
     my $self = shift;
@@ -18,7 +21,6 @@ sub execute {
     }
 }
 
-no Moose;
 __PACKAGE__->meta->make_immutable;
 
 1;
